Keyed

Trait Keyed 

pub trait Keyed<K> {
    // Required method
    fn key(&self) -> &K;
}
Trait for getting the key from a Leaf value

Required Methods

fn key(&self) -> &K

Return a reference to the key of the leaf type

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<K> Keyed<K> for K